@@ -34,12 +34,10 @@ import {
   fetchChartInstances,
 } from '../../routeHandlers/charts';
 import { keyBy } from 'lodash';
-
 import { createEncounterSchema } from '@tamanu/shared/schemas/facility/requests/createEncounter.schema';
 import { uploadAttachment } from '../../utils/uploadAttachment';
 import { noteChangelogsHandler, noteListHandler } from '../../routeHandlers';
 import { createPatientLetter } from '../../routeHandlers/createPatientLetter';
-
 import { getLabRequestList } from '../../routeHandlers/labs';
 import {
   deleteDocumentMetadata,
@@ -48,6 +46,7 @@ import {
 } from '../../routeHandlers/deleteModel';
 import { getPermittedSurveyIds } from '../../utils/getPermittedSurveyIds';
 import { validate } from '../../utils/validate';
+import { invoiceForResponse } from './invoice/invoiceForResponse';
 
 export const encounter = softDeletionCheckingRouter('Encounter');
 
@@ -55,13 +54,42 @@ encounter.get('/:id', simpleGet('Encounter', { auditAccess: true }));
 encounter.post(
   '/$',
   asyncHandler(async (req, res) => {
-    const { models, body, user } = req;
+    const {
+      models,
+      body: { facilityId, ...data },
+      user,
+    } = req;
     req.checkPermission('create', 'Encounter');
-    const validatedBody = validate(createEncounterSchema, body);
+
+    const validatedBody = validate(createEncounterSchema, data);
+
+    if (!validatedBody.endDate) {
+      const existingOpenEncounterCount = await models.Encounter.count({
+        where: {
+          patientId: validatedBody.patientId,
+          endDate: null,
+          deletedAt: null,
+        },
+      });
+
+      if (existingOpenEncounterCount > 0) {
+        throw new InvalidOperationError(
+          'This patient already has an active encounter. The active encounter must be discharged before a new active encounter can be created.',
+        );
+      }
+    }
+
     const encounterObject = await models.Encounter.create({ ...validatedBody, actorId: user.id });
 
-    if (body.dietIds) {
-      const dietIds = JSON.parse(body.dietIds);
+    await models.Invoice.automaticallyCreateForEncounter(
+      encounterObject.id,
+      encounterObject.encounterType,
+      encounterObject.startDate,
+      req.settings[facilityId],
+    );
+
+    if (data.dietIds) {
+      const dietIds = JSON.parse(data.dietIds);
       await encounterObject.addDiets(dietIds);
     }
     res.send(encounterObject);
@@ -146,11 +174,18 @@ encounter.put(
         await referral.update({ encounterId: id });
       }
 
+      if (req.body.locationId != null) {
+        const location = await models.Location.findByPk(req.body.locationId);
+        if (!location) {
+          throw new InvalidOperationError('Invalid location specified');
+        }
+      }
+
+      await encounterObject.update({ ...req.body, systemNote }, user);
       if (req.body.dietIds) {
         const dietIds = JSON.parse(req.body.dietIds);
         await encounterObject.setDiets(dietIds);
       }
-      await encounterObject.update({ ...req.body, systemNote }, user);
     });
     res.send(encounterObject);
   }),
@@ -555,9 +590,15 @@ encounterRelations.get(
     const invoiceRecord = await Invoice.findOne({
       where: { encounterId },
       include: Invoice.getFullReferenceAssociations(invoicePriceListId),
+      order: [
+        [{ model: models.InvoiceItem, as: 'items' }, 'orderDate', 'ASC'],
+        [{ model: models.InvoiceItem, as: 'items' }, 'createdAt', 'ASC'],
+        [{ model: models.InvoicePayment, as: 'payments' }, 'date', 'ASC'],
+      ],
     });
     if (!invoiceRecord) {
-      throw new NotFoundError('Invoice not found');
+      // Return null rather than a 404 as it is a valid scenario for there not to be an invoice
+      return res.send(null);
     }
 
     await req.audit.access({
@@ -566,7 +607,9 @@ encounterRelations.get(
       model: Invoice,
     });
 
-    res.send(invoiceRecord);
+    const responseRecord = invoiceForResponse(invoiceRecord);
+    const priceList = await InvoicePriceList.findByPk(invoicePriceListId, { raw: true });
+    res.send({ ...responseRecord, priceList });
   }),
 );
 
