@@ -2,17 +2,28 @@ import express from 'express';
 import asyncHandler from 'express-async-handler';
 import { QueryTypes } from 'sequelize';
 
-import { InvalidParameterError } from '@tamanu/errors';
+import { InvalidOperationError, InvalidParameterError, NotFoundError } from '@tamanu/errors';
 import { ENCOUNTER_TYPES, NOTE_TYPES } from '@tamanu/constants';
 
 import { renameObjectKeys } from '@tamanu/utils/renameObjectKeys';
 
-import { simpleGet, simplePut } from '@tamanu/shared/utils/crudHelpers';
+import { simpleGet } from '@tamanu/shared/utils/crudHelpers';
 
 export const triage = express.Router();
 
 triage.get('/:id', simpleGet('Triage', { auditAccess: true }));
-triage.put('/:id', simplePut('Triage'));
+triage.put(
+  '/:id',
+  asyncHandler(async (req, res) => {
+    const { models, params, user } = req;
+    req.checkPermission('read', 'Triage');
+    const triageObject = await models.Triage.findByPk(params.id);
+    if (!triageObject) throw new NotFoundError();
+    req.checkPermission('write', triageObject);
+    await triageObject.update(req.body, user);
+    res.send(triageObject);
+  }),
+);
 
 triage.post(
   '/$',
@@ -51,7 +62,7 @@ triage.post(
     const triageRecord = await models.Triage.create({ ...body, departmentId, actorId: user.id });
 
     if (vitals) {
-      const getDefaultId = async (type) =>
+      const getDefaultId = async type =>
         models.SurveyResponseAnswer.getDefaultId(type, settings[facilityId]);
       const updatedBody = {
         locationId: vitals.locationId || (await getDefaultId('location')),
@@ -78,7 +89,29 @@ triage.post(
     const encounter = await models.Encounter.findOne({
       where: { id: triageRecord.encounterId },
     });
-    await encounter.addTriageScoreNote(triageRecord, user);
+
+    const department = await models.Department.findOne({
+      where: { id: encounter.departmentId },
+    });
+
+    if (!department) {
+      throw new InvalidOperationError(
+        `Couldn’t record triage score as system note; no department found with with ID ‘${encounter.departmentId}’`,
+      );
+    }
+
+    await encounter.addSystemNote(
+      `${department.name} triage score: ${triageRecord.score}`,
+      triageRecord.triageTime,
+      user,
+    );
+
+    await models.Invoice.automaticallyCreateForEncounter(
+      encounter.id,
+      encounter.encounterType,
+      encounter.startDate,
+      settings[facilityId],
+    );
 
     res.send(triageRecord);
   }),
@@ -175,7 +208,7 @@ triage.get(
         },
       },
     );
-    const forResponse = result.map((x) => renameObjectKeys(x.forResponse()));
+    const forResponse = result.map(x => renameObjectKeys(x.forResponse()));
 
     res.send({
       data: forResponse,
